@@ -13,10 +13,6 @@
 G_BEGIN_DECLS
 
 
-/* --- ephy-dbus.h --- */
-#define EPHY_TYPE_DBUS_BUS ephy_dbus_bus_get_type()
-GType ephy_dbus_bus_get_type (void);
-
 /* --- ephy-link.h --- */
 #define EPHY_TYPE_LINK_FLAGS ephy_link_flags_get_type()
 GType ephy_link_flags_get_type (void);
@@ -28,6 +24,8 @@ GType ephy_session_command_get_type (void);
 /* --- ephy-shell.h --- */
 #define EPHY_TYPE_NEW_TAB_FLAGS ephy_new_tab_flags_get_type()
 GType ephy_new_tab_flags_get_type (void);
+#define EPHY_TYPE_STARTUP_FLAGS ephy_startup_flags_get_type()
+GType ephy_startup_flags_get_type (void);
 
 /* --- ephy-navigation-history-action.h --- */
 #define EPHY_TYPE_NAVIGATION_HISTORY_DIRECTION ephy_navigation_history_direction_get_type()
